@@ -27,6 +27,18 @@ pub struct Event {
     event: cl_event,
 }
 
+impl From<cl_event> for Event {
+    fn from(event: cl_event) -> Self {
+        Event { event }
+    }
+}
+
+impl From<Event> for cl_event {
+    fn from(value: Event) -> Self {
+        value.event as cl_event
+    }
+}
+
 impl Drop for Event {
     fn drop(&mut self) {
         release_event(self.event).expect("Error: clReleaseEvent");
@@ -58,29 +70,29 @@ impl Event {
 
     pub fn command_execution_status(&self) -> Result<CommandExecutionStatus> {
         Ok(CommandExecutionStatus(
-            get_event_info(self.event, EventInfo::CL_EVENT_COMMAND_EXECUTION_STATUS)?.to_int(),
+            get_event_info(self.event, EventInfo::CL_EVENT_COMMAND_EXECUTION_STATUS)?.into(),
         ))
     }
 
     pub fn command_type(&self) -> Result<EventCommandType> {
         Ok(EventCommandType(
-            get_event_info(self.event, EventInfo::CL_EVENT_COMMAND_TYPE)?.to_uint(),
+            get_event_info(self.event, EventInfo::CL_EVENT_COMMAND_TYPE)?.into(),
         ))
     }
 
     pub fn reference_count(&self) -> Result<cl_uint> {
-        Ok(get_event_info(self.event, EventInfo::CL_EVENT_REFERENCE_COUNT)?.to_uint())
+        Ok(get_event_info(self.event, EventInfo::CL_EVENT_REFERENCE_COUNT)?.into())
     }
 
     pub fn command_queue(&self) -> Result<cl_command_queue> {
-        Ok(
-            get_event_info(self.event, EventInfo::CL_EVENT_COMMAND_QUEUE)?.to_ptr()
-                as cl_command_queue,
-        )
+        Ok(isize::from(get_event_info(
+            self.event,
+            EventInfo::CL_EVENT_COMMAND_QUEUE,
+        )?) as cl_command_queue)
     }
 
     pub fn context(&self) -> Result<cl_context> {
-        Ok(get_event_info(self.event, EventInfo::CL_EVENT_CONTEXT)?.to_ptr() as cl_context)
+        Ok(isize::from(get_event_info(self.event, EventInfo::CL_EVENT_CONTEXT)?) as cl_context)
     }
 
     pub fn set_callback(
@@ -100,36 +112,30 @@ impl Event {
     pub fn profiling_command_queued(&self) -> Result<cl_ulong> {
         Ok(
             get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_QUEUED)?
-                .to_ulong(),
+                .into(),
         )
     }
 
     pub fn profiling_command_submit(&self) -> Result<cl_ulong> {
         Ok(
             get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_SUBMIT)?
-                .to_ulong(),
+                .into(),
         )
     }
 
     pub fn profiling_command_start(&self) -> Result<cl_ulong> {
-        Ok(
-            get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_START)?
-                .to_ulong(),
-        )
+        Ok(get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_START)?.into())
     }
 
     pub fn profiling_command_end(&self) -> Result<cl_ulong> {
-        Ok(
-            get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_END)?
-                .to_ulong(),
-        )
+        Ok(get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_END)?.into())
     }
 
     /// CL_VERSION_2_0
     pub fn profiling_command_complete(&self) -> Result<cl_ulong> {
         Ok(
             get_event_profiling_info(self.event, ProfilingInfo::CL_PROFILING_COMMAND_COMPLETE)?
-                .to_ulong(),
+                .into(),
         )
     }
 }
