@@ -38,6 +38,12 @@ pub struct Kernel {
     kernel: cl_kernel,
 }
 
+impl From<Kernel> for cl_kernel {
+    fn from(value: Kernel) -> Self {
+        value.kernel
+    }
+}
+
 #[cfg(feature = "CL_VERSION_2_1")]
 impl Clone for Kernel {
     /// Clone an OpenCL kernel object.  
@@ -148,27 +154,27 @@ impl Kernel {
     }
 
     pub fn function_name(&self) -> Result<String> {
-        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_FUNCTION_NAME)?.to_string())
+        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_FUNCTION_NAME)?.into())
     }
 
     pub fn num_args(&self) -> Result<cl_uint> {
-        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_NUM_ARGS)?.to_uint())
+        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_NUM_ARGS)?.into())
     }
 
     pub fn reference_count(&self) -> Result<cl_uint> {
-        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_REFERENCE_COUNT)?.to_uint())
+        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_REFERENCE_COUNT)?.into())
     }
 
     pub fn context(&self) -> Result<cl_context> {
-        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_CONTEXT)?.to_ptr() as cl_context)
+        Ok(isize::from(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_CONTEXT)?) as cl_context)
     }
 
     pub fn program(&self) -> Result<cl_program> {
-        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_PROGRAM)?.to_ptr() as cl_program)
+        Ok(isize::from(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_PROGRAM)?) as cl_program)
     }
 
     pub fn attributes(&self) -> Result<String> {
-        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_ATTRIBUTES)?.to_string())
+        Ok(get_kernel_info(self.kernel, KernelInfo::CL_KERNEL_ATTRIBUTES)?.into())
     }
 
     #[cfg(feature = "CL_VERSION_1_2")]
@@ -178,7 +184,7 @@ impl Kernel {
             arg_indx,
             KernelArgInfo::CL_KERNEL_ARG_ADDRESS_QUALIFIER,
         )?
-        .to_uint())
+        .into())
     }
 
     #[cfg(feature = "CL_VERSION_1_2")]
@@ -188,7 +194,7 @@ impl Kernel {
             arg_indx,
             KernelArgInfo::CL_KERNEL_ARG_ACCESS_QUALIFIER,
         )?
-        .to_uint())
+        .into())
     }
 
     #[cfg(feature = "CL_VERSION_1_2")]
@@ -198,7 +204,7 @@ impl Kernel {
             arg_indx,
             KernelArgInfo::CL_KERNEL_ARG_TYPE_QUALIFIER,
         )?
-        .to_ulong())
+        .into())
     }
 
     #[cfg(feature = "CL_VERSION_1_2")]
@@ -208,15 +214,12 @@ impl Kernel {
             arg_indx,
             KernelArgInfo::CL_KERNEL_ARG_TYPE_NAME,
         )?
-        .to_string())
+        .into())
     }
 
     #[cfg(feature = "CL_VERSION_1_2")]
     pub fn get_arg_name(&self, arg_indx: cl_uint) -> Result<String> {
-        Ok(
-            get_kernel_arg_info(self.kernel, arg_indx, KernelArgInfo::CL_KERNEL_ARG_NAME)?
-                .to_string(),
-        )
+        Ok(get_kernel_arg_info(self.kernel, arg_indx, KernelArgInfo::CL_KERNEL_ARG_NAME)?.into())
     }
 
     pub fn get_work_group_size(&self, device: cl_device_id) -> Result<size_t> {
@@ -225,7 +228,7 @@ impl Kernel {
             device,
             KernelWorkGroupInfo::CL_KERNEL_WORK_GROUP_SIZE,
         )?
-        .to_size())
+        .into())
     }
 
     pub fn get_compile_work_group_size(&self, device: cl_device_id) -> Result<Vec<size_t>> {
@@ -234,7 +237,7 @@ impl Kernel {
             device,
             KernelWorkGroupInfo::CL_KERNEL_COMPILE_WORK_GROUP_SIZE,
         )?
-        .to_vec_size())
+        .into())
     }
 
     pub fn get_local_mem_size(&self, device: cl_device_id) -> Result<cl_ulong> {
@@ -243,7 +246,7 @@ impl Kernel {
             device,
             KernelWorkGroupInfo::CL_KERNEL_LOCAL_MEM_SIZE,
         )?
-        .to_ulong())
+        .into())
     }
 
     pub fn get_work_group_size_multiple(&self, device: cl_device_id) -> Result<size_t> {
@@ -252,7 +255,7 @@ impl Kernel {
             device,
             KernelWorkGroupInfo::CL_KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE,
         )?
-        .to_size())
+        .into())
     }
 
     pub fn get_private_mem_size(&self, device: cl_device_id) -> Result<cl_ulong> {
@@ -261,7 +264,7 @@ impl Kernel {
             device,
             KernelWorkGroupInfo::CL_KERNEL_PRIVATE_MEM_SIZE,
         )?
-        .to_ulong())
+        .into())
     }
 
     #[cfg(feature = "cl_khr_subgroups")]
