@@ -50,6 +50,18 @@ pub struct Platform {
     id: intptr_t,
 }
 
+impl From<cl_platform_id> for Platform {
+    fn from(value: cl_platform_id) -> Self {
+        Platform { id: value as intptr_t }
+    }
+}
+
+impl From<Platform> for cl_platform_id {
+    fn from(value: Platform) -> Self {
+        value.id as cl_platform_id
+    }
+}
+
 unsafe impl Send for Platform {}
 unsafe impl Sync for Platform {}
 
@@ -63,7 +75,7 @@ impl Platform {
         self.id as cl_platform_id
     }
 
-    /// Get the list of available devices of the given type on the Platform.
+    /// Get the ids of available devices of the given type on the Platform.
     /// # Examples
     /// ```
     /// use opencl3::platform::get_platforms;
@@ -150,7 +162,7 @@ impl Platform {
     pub fn profile(&self) -> Result<String> {
         Ok(
             platform::get_platform_info(self.id(), platform::PlatformInfo::CL_PLATFORM_PROFILE)?
-                .to_string(),
+                .into(),
         )
     }
 
@@ -159,7 +171,7 @@ impl Platform {
     pub fn version(&self) -> Result<String> {
         Ok(
             platform::get_platform_info(self.id(), platform::PlatformInfo::CL_PLATFORM_VERSION)?
-                .to_string(),
+                .into(),
         )
     }
 
@@ -167,7 +179,7 @@ impl Platform {
     pub fn name(&self) -> Result<String> {
         Ok(
             platform::get_platform_info(self.id(), platform::PlatformInfo::CL_PLATFORM_NAME)?
-                .to_string(),
+                .into(),
         )
     }
 
@@ -175,7 +187,7 @@ impl Platform {
     pub fn vendor(&self) -> Result<String> {
         Ok(
             platform::get_platform_info(self.id(), platform::PlatformInfo::CL_PLATFORM_VENDOR)?
-                .to_string(),
+                .into(),
         )
     }
 
@@ -183,7 +195,7 @@ impl Platform {
     pub fn extensions(&self) -> Result<String> {
         Ok(
             platform::get_platform_info(self.id(), platform::PlatformInfo::CL_PLATFORM_EXTENSIONS)?
-                .to_string(),
+                .into(),
         )
     }
 
@@ -195,7 +207,7 @@ impl Platform {
             self.id(),
             platform::PlatformInfo::CL_PLATFORM_HOST_TIMER_RESOLUTION,
         )?
-        .to_ulong())
+        .into())
     }
 
     /// The detailed (major, minor, patch) version supported by the platform.  
@@ -205,7 +217,7 @@ impl Platform {
             self.id(),
             platform::PlatformInfo::CL_PLATFORM_NUMERIC_VERSION,
         )?
-        .to_uint())
+        .into())
     }
 
     /// An array of description (name and version) structures that lists all the
@@ -216,7 +228,7 @@ impl Platform {
             self.id(),
             platform::PlatformInfo::CL_PLATFORM_EXTENSIONS_WITH_VERSION,
         )?
-        .to_vec_name_version())
+        .into())
     }
 
     /// Unload an OpenCL compiler for a platform.
