@@ -87,6 +87,12 @@ pub struct Program {
     kernel_names: String,
 }
 
+impl From<Program> for cl_program {
+    fn from(value: Program) -> Self {
+        value.program as cl_program
+    }
+}
+
 impl Drop for Program {
     fn drop(&mut self) {
         release_program(self.program).expect("Error: clReleaseProgram");
@@ -240,18 +246,17 @@ impl Program {
         sources: &[&str],
         options: &str,
     ) -> result::Result<Program, String> {
-        let mut program =
-            Program::create_from_sources(context, sources).map_err(|e| e.to_string())?;
+        let mut program = Program::create_from_sources(context, sources).map_err(String::from)?;
         match program.build(context.devices(), options) {
             Ok(_) => Ok(program),
             Err(e) => {
                 if CL_BUILD_PROGRAM_FAILURE == e.0 {
                     let log = program
                         .get_build_log(context.devices()[0])
-                        .map_err(|e| e.to_string())?;
-                    Err(e.to_string() + ", build log: " + &log)
+                        .map_err(String::from)?;
+                    Err(String::from(e) + ", build log: " + &log)
                 } else {
-                    Err(e.to_string())
+                    Err(String::from(e))
                 }
             }
         }
@@ -420,64 +425,63 @@ impl Program {
     }
 
     pub fn get_reference_count(&self) -> Result<cl_uint> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_REFERENCE_COUNT)?.to_uint())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_REFERENCE_COUNT)?.into())
     }
 
     pub fn get_context(&self) -> Result<cl_context> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_CONTEXT)?.to_ptr() as cl_context)
+        Ok(intptr_t::from(get_program_info(
+            self.program,
+            ProgramInfo::CL_PROGRAM_CONTEXT,
+        )?) as cl_context)
     }
 
     pub fn get_num_devices(&self) -> Result<cl_uint> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_NUM_DEVICES)?.to_uint())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_NUM_DEVICES)?.into())
     }
 
     pub fn get_devices(&self) -> Result<Vec<intptr_t>> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_DEVICES)?.to_vec_intptr())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_DEVICES)?.into())
     }
 
     pub fn get_source(&self) -> Result<String> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_SOURCE)?.to_string())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_SOURCE)?.into())
     }
 
     pub fn get_binary_sizes(&self) -> Result<Vec<size_t>> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_BINARY_SIZES)?.to_vec_size())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_BINARY_SIZES)?.into())
     }
 
     pub fn get_binaries(&self) -> Result<Vec<Vec<cl_uchar>>> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_BINARIES)?.to_vec_vec_uchar())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_BINARIES)?.into())
     }
 
     pub fn get_num_kernels(&self) -> Result<size_t> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_NUM_KERNELS)?.to_size())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_NUM_KERNELS)?.into())
     }
 
     pub fn get_kernel_names(&self) -> Result<String> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_KERNEL_NAMES)?.to_string())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_KERNEL_NAMES)?.into())
     }
 
     /// CL_VERSION_2_1
     pub fn get_program_il(&self) -> Result<String> {
-        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_IL)?.to_string())
+        Ok(get_program_info(self.program, ProgramInfo::CL_PROGRAM_IL)?.into())
     }
 
     /// CL_VERSION_2_2
     pub fn get_program_scope_global_ctors_present(&self) -> Result<bool> {
-        Ok(get_program_info(
+        Ok(cl_uint::from(get_program_info(
             self.program,
             ProgramInfo::CL_PROGRAM_SCOPE_GLOBAL_CTORS_PRESENT,
-        )?
-        .to_uint()
-            != CL_FALSE)
+        )?) != CL_FALSE)
     }
 
     /// CL_VERSION_2_2
     pub fn get_program_scope_global_dtors_present(&self) -> Result<bool> {
-        Ok(get_program_info(
+        Ok(cl_uint::from(get_program_info(
             self.program,
             ProgramInfo::CL_PROGRAM_SCOPE_GLOBAL_DTORS_PRESENT,
-        )?
-        .to_uint()
-            != CL_FALSE)
+        )?) != CL_FALSE)
     }
 
     pub fn get_build_status(&self, device: cl_device_id) -> Result<cl_int> {
@@ -486,7 +490,7 @@ impl Program {
             device,
             ProgramBuildInfo::CL_PROGRAM_BUILD_STATUS,
         )?
-        .to_int())
+        .into())
     }
 
     pub fn get_build_options(&self, device: cl_device_id) -> Result<String> {
@@ -495,13 +499,13 @@ impl Program {
             device,
             ProgramBuildInfo::CL_PROGRAM_BUILD_OPTIONS,
         )?
-        .to_string())
+        .into())
     }
 
     pub fn get_build_log(&self, device: cl_device_id) -> Result<String> {
         Ok(
             get_program_build_info(self.program, device, ProgramBuildInfo::CL_PROGRAM_BUILD_LOG)?
-                .to_string(),
+                .into(),
         )
     }
 
@@ -511,7 +515,7 @@ impl Program {
             device,
             ProgramBuildInfo::CL_PROGRAM_BINARY_TYPE,
         )?
-        .to_uint())
+        .into())
     }
 
     /// CL_VERSION_2_0
@@ -521,7 +525,7 @@ impl Program {
             device,
             ProgramBuildInfo::CL_PROGRAM_BUILD_GLOBAL_VARIABLE_TOTAL_SIZE,
         )?
-        .to_size())
+        .into())
     }
 }
 
